# -*- coding: utf-8 -*-

# Contributors:
#    Antonio López Martínez-Carrasco <antoniolopezmc1995@gmail.com>

"""This file contains the implementation of the mapper that follows a Zero-Shot approach and uses LLMs from ollama.
"""
from pandas import DataFrame

class ZeroShotAndOllama(object):
    pass
